Module builder

Module builder 

Format-neutral archive construction.

Archive formats implement ArchiveBuilder and wrap the resulting writer in a stateful Builder to use the format-neutral construction APIs.

Structs

BuildFailure
A failure returned by an ArchiveBuilder format hook.
Builder
A stateful format-neutral archive construction engine.
BuilderPolicy
Controls format-neutral archive construction behavior.
EntryMetadata
Minimal regular-file metadata accepted by Builder::add_entry.
EntryPayload
A format-neutral, uncompressed payload supplied to an ArchiveBuilder implementation.

Enums

BuildError
A failure while constructing an archive.
SymlinkPolicy
Controls how source symbolic links are handled during recursive builds.
TraversalError
A failure while traversing a recursive archive source.

Traits

ArchiveBuilder
A format-specific archive writer that can create a stateful Builder.