pub struct EntryPayload<'a> { /* private fields */ }Expand description
A format-neutral, uncompressed payload supplied to an ArchiveBuilder
implementation.
Implementations
Sourceimpl EntryPayload<'_>
impl EntryPayload<'_>
Sourcepub fn size(&self) -> u64
pub fn size(&self) -> u64
Returns the logical, uncompressed source size in bytes.
This is the total number of bytes yielded by Self::next_chunk, not
necessarily the size ultimately stored by the archive format.
Sourcepub async fn next_chunk<E>(&mut self) -> Result<Option<&[u8]>, BuildError<E>>
pub async fn next_chunk<E>(&mut self) -> Result<Option<&[u8]>, BuildError<E>>
Returns the next chunk of logical, uncompressed source bytes.