Module decode

Module decode 

Member-oriented decoding of pax or GNU tar streams.

Structs

DecodePolicy
Controls which otherwise valid tar features member decoding may accept.
PaxDecodePolicy
Controls which otherwise valid pax features member decoding may accept.
TarArchive
A one-pass reader for a validated pax or GNU tar archive.
TarMemberPayload
A tar member payload adapted to MemberPayloadTrait.

Enums

DecodeError
An error produced while decoding tar members.
DecodePolicyViolation
A valid tar feature rejected by the selected DecodePolicy.

Constants

DEFAULT_MAX_GLOBAL_PAX_EXTENSIONS_SIZE
The default maximum cumulative size of global pax extensions before one member.
DEFAULT_MAX_GNU_EXTENSION_SIZE
The default maximum size in bytes of one GNU metadata extension.
DEFAULT_MAX_PAX_EXTENSION_SIZE
The default maximum size in bytes of one local or global pax extension.