pub enum DecodePolicyViolation {
GnuArchive,
GlobalPaxExtension,
PaxVendorExtension {
vendor: String,
name: String,
},
NonUtf8PaxVendorValue {
vendor: String,
name: String,
},
DuplicatePaxRecord {
keyword: String,
},
GlobalPaxMemberMetadata {
keyword: &'static str,
},
}Expand description
A tar feature accepted by framing but rejected by the selected DecodePolicy.
Variants
GnuArchive
A GNU-family frame appeared when only POSIX-pax decoding is allowed.
GlobalPaxExtension
A global POSIX pax extended header appeared when it is forbidden.
PaxVendorExtension
A vendor-namespaced POSIX pax record appeared.
NonUtf8PaxVendorValue
A vendor-namespaced POSIX pax record contains a non-UTF-8 value.
DuplicatePaxRecord
One POSIX pax extended header repeats the same logical keyword.
GlobalPaxMemberMetadata
A global POSIX pax header supplies per-member identity or framing data.