BuildError

Enum BuildError 

pub enum BuildError<E> {
    Encoder(E),
    Traversal(TraversalError),
    InvalidArchivePath {
        path: PathBuf,
        reason: &'static str,
    },
    NameRejected {
        context: &'static str,
        value: String,
    },
    PathCollision {
        path: String,
    },
    Filesystem {
        operation: &'static str,
        path: PathBuf,
        source: Error,
    },
    BlockingTask(JoinError),
    Poisoned,
    ArithmeticOverflow {
        context: &'static str,
    },
}
A failure while constructing an archive.

Variants



Encoder(E)

The archive format encoder failed.



Traversal(TraversalError)

Traversing a recursive source failed.



InvalidArchivePath

A requested archive path cannot be represented by the UTF-8 builder.

Fields

path: PathBuf

The rejected archive path.

reason: &'static str

The reason the path cannot be represented.



NameRejected

An archive name was rejected by the configured BuilderPolicy.

Fields

context: &'static str

The role of the rejected archive text.

value: String

The rejected UTF-8 value.



PathCollision

An archive path collides with a previously reserved entry.

Fields

path: String

The conflicting normalized archive path.



Filesystem

A source filesystem operation failed.

Fields

operation: &'static str

The operation that failed.

path: PathBuf

The affected source filesystem path.

source: Error

The underlying I/O error.



BlockingTask(JoinError)

A blocking filesystem operation failed to complete.



Poisoned

The builder cannot continue because a prior failure may have written bytes.



ArithmeticOverflow

A size computation exceeded this API’s range.

Fields

context: &'static str

The failed computation.