ExtractError

Enum ExtractError 

pub enum ExtractError<E> {
    Archive(E),
    Filesystem {
        operation: &'static str,
        path: PathBuf,
        source: Error,
    },
    BlockingTask(JoinError),
    UnsafePath {
        position: u64,
        context: &'static str,
        value: String,
        reason: &'static str,
    },
    PathCollision {
        path: PathBuf,
    },
    UnsupportedMember {
        position: u64,
        path: PathBuf,
        kind: SpecialKind,
    },
    InvalidLink {
        position: u64,
        path: PathBuf,
        target: String,
        reason: &'static str,
    },
    PolicyViolation {
        position: u64,
        violation: ExtractPolicyViolation,
    },
}
An error produced while securely extracting an archive.

Variants



Archive(E)

Reading or decoding the underlying archive failed.



Filesystem

A destination filesystem operation failed.

Fields

operation: &'static str

The operation that failed.

path: PathBuf

The path involved in the failed operation.

source: Error

The underlying I/O error.



BlockingTask(JoinError)

A blocking extraction operation failed to complete.



UnsafePath

An archive member path or link value is unsafe to extract.

Fields

position: u64

Source member position.

context: &'static str

Whether this is a member path or link target.

value: String

Archive-provided value.

reason: &'static str

Rejection reason.



PathCollision

An archive entry collides with a path that cannot be replaced.

Fields

path: PathBuf

Normalized extraction-relative path.



UnsupportedMember

A special member kind is deliberately excluded from extraction.

Fields

position: u64

Source member position.

path: PathBuf

Normalized extraction-relative path.

kind: SpecialKind

Unsupported special-file kind.

A symbolic or hard link cannot be safely resolved.

Fields

position: u64

Source member position.

path: PathBuf

Normalized link path.

target: String

Archive-provided or normalized link target.

reason: &'static str

Rejection reason.



PolicyViolation

A structurally valid member was rejected by extraction policy.

Fields

position: u64

Source member position.

violation: ExtractPolicyViolation

The selected policy rule that rejected the member.