TraversalError

Enum TraversalError 

pub enum TraversalError {
    InvalidArchivePath {
        path: PathBuf,
        reason: &'static str,
    },
    NameRejected {
        context: &'static str,
        value: String,
    },
    NonUtf8SourcePath {
        path: PathBuf,
    },
    NonUtf8LinkTarget {
        path: PathBuf,
    },
    SourceNotDirectory {
        path: PathBuf,
    },
    SymbolicLinkRejected {
        path: PathBuf,
    },
    UnsupportedFilesystemType {
        path: PathBuf,
    },
    Filesystem {
        operation: &'static str,
        path: PathBuf,
        source: Error,
    },
    BlockingTask(JoinError),
}
A failure while traversing a recursive archive source.

Variants



InvalidArchivePath

A traversed source entry unexpectedly falls outside the recursive root.

Fields

path: PathBuf

The source entry outside the recursive root.

reason: &'static str

The failed traversal invariant.



NameRejected

An archive name was rejected by the configured builder policy.

Fields

context: &'static str

The role of the rejected archive text.

value: String

The rejected UTF-8 value.



NonUtf8SourcePath

A source path component cannot be represented by this UTF-8-only builder.

Fields

path: PathBuf

The affected source filesystem path.



NonUtf8LinkTarget

A symbolic-link target cannot be represented by this UTF-8-only builder.

Fields

path: PathBuf

The affected symbolic-link source path.



SourceNotDirectory

The recursive source directory is not a real directory.

Fields

path: PathBuf

The rejected source directory.



SymbolicLinkRejected

The builder policy rejects source symbolic links.

Fields

path: PathBuf

The rejected symbolic link.



UnsupportedFilesystemType

The recursive source contains a filesystem node outside the supported subset.

Fields

path: PathBuf

The rejected source filesystem path.



Filesystem

A source traversal filesystem operation failed.

Fields

operation: &'static str

The operation that failed.

path: PathBuf

The affected source filesystem path.

source: Error

The underlying I/O error.



BlockingTask(JoinError)

The blocking traversal task failed to complete.