pub enum BuildError<E> {
Encoder(E),
Traversal(TraversalError),
InvalidArchivePath {
path: PathBuf,
reason: &'static str,
},
NameRejected {
context: &'static str,
value: String,
},
PathCollision {
path: String,
},
Filesystem {
operation: &'static str,
path: PathBuf,
source: Error,
},
BlockingTask(JoinError),
Poisoned,
ArithmeticOverflow {
context: &'static str,
},
}Expand description
A failure while constructing an archive.
Variants
Encoder(E)
The archive format encoder failed.
Traversal(TraversalError)
Traversing a recursive source failed.
InvalidArchivePath
A requested archive path cannot be represented by the UTF-8 builder.
Fields
NameRejected
An archive name was rejected by the configured BuilderPolicy.
Fields
PathCollision
An archive path collides with a previously reserved entry.
Filesystem
A source filesystem operation failed.
Fields
BlockingTask(JoinError)
A blocking filesystem operation failed to complete.
Poisoned
The builder cannot continue because a prior failure may have written bytes.
ArithmeticOverflow
A size computation exceeded this API’s range.